We have a registration statement on file with the SEC using a 'shelf' registration process. Under this shelf registration process, we may offer  and sell, from time to time, any combination of the securities described in a prospectus to the registration statement, including registered  debt, provided we maintain Well-known Seasoned Issuer ('WKSI') status.

We maintain trade and standby letters of credit to facilitate international payments. As of January 31, 2015, we have $8 available under a  trade letter of credit, with $1 outstanding, and $15 available under the standby letter of credit, with $7 outstanding at the end of the year.

Plans for our Manhattan full-line store, which we currently expect to open in late 2018 to 2019, ultimately include owning a condominium  interest in a mixed-use tower and leasing certain nearby properties. As of January 31, 2015, we had approximately $125 of fee interest in  land, which is expected to convert to the condominium interest once the store is constructed. We have committed to make future installment  payments based on the developer meeting pre-established construction and development milestones. Our fee interest in the land is currently  and will continue to be subject to lien by project development lenders until project completion or fulfillment of our existing installment payment  commitment. In the unlikely event that this project is not completed, the opening may be delayed and we may potentially be subject to future  losses or capital commitments in order to complete construction or to monetize our previous investments in the land.

### Impact of Credit Ratings

Under the terms of our revolver, any borrowings we may enter into will accrue interest for Euro-Dollar Rate Loans at a floating base rate tied  to LIBOR, for Canadian Dealer Offer Rate Loans at a floating rate tied to CDOR, and for Base Rate Loans at the highest of: (i) the Euro- Dollar rate plus 100 basis points, (ii) the federal funds rate plus 50 basis points and (iii) the prime rate.

The rate depends upon the type of borrowing incurred, plus in each case an applicable margin. This applicable margin varies depending  upon the credit ratings assigned to our long-term unsecured debt. At the time of this report, our long-term unsecured debt ratings, outlook  and resulting applicable margin were as follows:

Should the ratings assigned to our long-term unsecured debt improve, the applicable margin associated with any such borrowings may  decrease, resulting in a slightly lower borrowing cost under this facility. Should the ratings assigned to our long-term unsecured debt worsen,  the applicable margin associated with our borrowings may increase, resulting in a slightly higher borrowing cost under this facility.

### Debt Covenants

The revolver requires that we maintain an adjusted debt to earnings before interest, income taxes, depreciation, amortization and rent  ('EBITDAR') leverage ratio of less than four times (see the following additional discussion of Adjusted Debt to EBITDAR).

As of January 31, 2015 and February 1, 2014, we were in compliance with this covenant. We will continue to monitor this covenant and  believe that we will remain in compliance with this covenant during 2015.

30